@@ -1,14 +1,15 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2022, by Samuel Williams.
+# Copyright, 2022-2024, by Samuel Williams.
+# Copyright, 2023, by Math Ieu.
 
-require 'io/event'
-require 'io/event/selector'
-require 'io/event/debug/selector'
+require "io/event"
+require "io/event/selector"
+require "io/event/debug/selector"
 
-require 'socket'
-require 'fiber'
+require "socket"
+require "fiber"
 
 ProcessIO = Sus::Shared("process io") do
 	it "can wait for a process which has terminated already" do
@@ -29,7 +30,11 @@ ProcessIO = Sus::Shared("process io") do
 		end
 		
 		fiber.transfer
-		selector.select(1)
+		
+		# Wait until the result is collected:
+		until result
+			selector.select(1)
+		end
 		
 		expect(result.success?).to be == true
 	end
@@ -39,12 +44,12 @@ IO::Event::Selector.constants.each do |name|
 	klass = IO::Event::Selector.const_get(name)
 	
 	describe(klass, unique: name) do
-		def before
+		before do
 			@loop = Fiber.current
 			@selector = subject.new(@loop)
 		end
 		
-		def after
+		after do
 			@selector&.close
 		end
 		
